@@ -13,7 +13,7 @@ class AdministrationUtility(CommandLineUtility):
     
     def __init__(self): #, systemPath=None):
         CommandLineUtility.__init__(self) # old style class
-        self.appInstance= None
+        self.appInstance = None
         self.interactive = 0
         self.prompt = '> '
         #self.systemPath = systemPath
@@ -46,6 +46,25 @@ class AdministrationUtility(CommandLineUtility):
         self.args = [arg.strip() for arg in unstrippedArgs]
         return self.args
 
+    def do_setup(self, line=None):
+        self.createFilesystem()
+        try:
+            self.takeDatabaseAction('create')
+        except Exception, inst:
+            print "Warning: Couldn't create the database: %s" % inst
+            print "Trying to init the database anyway..."
+        self.takeDatabaseAction('init')
+        self.buildApplication()
+        self.buildApacheConfig()
+
+    def help_setup(self, line=None):
+        usage = \
+'''setup
+
+Create service from configuration (files, database, Apache config).
+'''
+        print usage
+
     def do_migratedump(self, line=None):
         self.convertLineToArgs(line)
         if len(self.args) != 1:
@@ -118,31 +137,6 @@ Dump service filesystem files
 '''migrateload filepath
 
 Load migrated service data
-'''
-        print usage
-
-    def do_data(self, line=None):
-        args = self.convertLineToArgs(line)
-        if len(args) != 1:
-            print 'Error: Insufficient arguments\n'
-            self.help_data(line)
-            return 1
-        elif args[0] == 'create':
-            self.initialiseSystemServiceFilesystem()
-            return 0
-        else:
-            self.help_data()
-            return 1
-
-    def initialiseSystemServiceFilesystem(self):
-        raise Exception, "Method not implemented."
-
-    def help_data(self, line=None):
-        usage = \
-'''data <action>
-  action = create
-
-Create environment data
 '''
         print usage
 
@@ -192,8 +186,9 @@ Create environment data
             return 1
        
     def takeDatabaseAction(self, actionName):
+        dictionary = self.constructSystemDictionary() # Need to have DJANGO_SETTING_MODULE set.
         dbUtilClass = self.getDatabaseUtilityClass()
-        dbUtil = dbUtilClass()
+        dbUtil = dbUtilClass() # Todo: Pass in the dictionary.
         actionMethod = getattr(dbUtil, actionName)
         actionMethod()
 
@@ -250,6 +245,41 @@ you cannot run any other db commands again in the same session.'''
 Upgrade a deployment (files and database)'''
         print usage
     
+    def do_fs(self, line=None):
+        args = self.convertLineToArgs(line)
+        if len(args) == 0:
+            print 'Error: Insufficient arguments\n'
+            self.help_fs(line)
+            return 1
+        elif args[0] == 'create':
+            try:
+                self.createFilesystem()
+                return 0
+            except Exception, inst:
+                print "Error: Couldn't create filesystem: %s" % str(inst)
+        else:
+            self.help_fs()
+            return 1
+
+    def help_fs(self, line=None):
+        usage = \
+'''fs create 
+
+Install template and media files to filesystem paths set in your
+service configuration file (see 'templates_dir' and 'media_dir').
+'''
+        print usage
+
+    def createFilesystem(self):
+        from dm.command.initialise import InitialiseFilesystem
+        dictionary = self.constructSystemDictionary()
+        command = InitialiseFilesystem(dictionary)
+        command.execute()
+
+    def constructSystemDictionary(self):
+        from dm.dictionary import SystemDictionary
+        return SystemDictionary()
+
     def do_apacheconfig(self, line=None):
         args = self.convertLineToArgs(line)
         if len(args) == 0:
@@ -286,6 +316,13 @@ Upgrade a deployment (files and database)'''
             self.help_apacheconfig(line)
             return 1
 
+    def help_apacheconfig(self, line=None):
+        help = 'apacheconfig [ create | reload | path]\n'
+        help += '\tcreate: create web server configuration\n'
+        help += '\treload: reload web server configuration\n'
+        help += '\tpath: prints path to web server configuration\n'
+        print help
+
     def buildApacheConfig(self):
         configBuilder = self.createApacheConfigBuilder()
         configBuilder.buildConfigFile()
@@ -307,13 +344,6 @@ Upgrade a deployment (files and database)'''
         from dm.apache.config import ApacheConfigBuilder
         return ApacheConfigBuilder
 
-    def help_apacheconfig(self, line=None):
-        help = 'apacheconfig [ create | reload | path]\n'
-        help += '\tcreate: create web server configuration\n'
-        help += '\treload: reload web server configuration\n'
-        help += '\tpath: prints path to web server configuration\n'
-        print help
-
     def do_www(self, line=None):
         return self.do_apacheconfig(line)
 
@@ -337,9 +367,6 @@ http://knowledgeforge.net/kforge/svn/trunk/docs/cli_shell.txt
     def do_about(self, args=None):
         print self.createAboutMessage()
 
-    def createAboutMessage(self):
-        raise Exception, "Method not implemented."
-
     def help_about(self, line=None):
         help = \
 '''about: print basic information about this application
@@ -347,6 +374,8 @@ http://knowledgeforge.net/kforge/svn/trunk/docs/cli_shell.txt
 '''
         print help
 
+    def createAboutMessage(self):
+        raise Exception, "Method not implemented."
 
     def do_help(self, line=None):
         CommandLineUtility.do_help(self, line)
@@ -410,10 +439,10 @@ class UtilityRunner(object):
             self.runUtilityOnce('about')
             return
         else:
-            if self.options.config_file_path:
+            if self.options.configPath:
                 # Set the environment from the option.
-                filePath = os.path.abspath(self.options.config_file_path)
-                os.environ[self.configFilePathEnvironVariableName] = filePath
+                configFilePath = os.path.abspath(self.options.configPath)
+                os.environ[self.configFilePathEnvironVariableName] = configFilePath
             #if self.options.system_path:
             #    self.systemPath = self.options.system_path
             if self.isScriptRequest():
@@ -424,13 +453,9 @@ class UtilityRunner(object):
                     errorStatus = self.runUtilityInteractive()
                     sys.exit(errorStatus)
                 elif len(self.args) > 0:
+
                     if not os.environ.get(self.configFilePathEnvironVariableName, ''):
-                        envVarName = self.configFilePathEnvironVariableName
                         raise MissingConfigurationPath
-                        print 'Path to configuration file has not been set.'
-                        print 'Please set KFORGE_SETTINGS in environment,'
-                        print 'or alternatively use the --config option.'
-                        sys.exit(1)
                     #self.handleNullArgs()
                     errorStatus = self.runUtilityOnce(self.line)
                     sys.exit(errorStatus)
@@ -438,7 +463,7 @@ class UtilityRunner(object):
                     self.handleNullArgs()
             except MissingConfigurationPath, inst:
                 print 'Path to configuration file has not been set.'
-                print 'Please set KFORGE_SETTINGS in environment,'
+                print 'Please set %s in environment,' % self.configFilePathEnvironVariableName
                 print 'or alternatively use the --config option.'
                 sys.exit(1)
                 
@@ -455,14 +480,6 @@ class UtilityRunner(object):
         #raise Exception, self.optionParser.print_usage()
         
     def createOptionParserOptions(self):
-        self.optionParser.add_option(
-            '-i', '--interactive',
-            action='store_true',
-            dest='interactive',
-            default=False,
-            help='Run in interactive mode. If this option is' + \
-                 ' specified any commands at invocation will be ignored.'
-        )
         self.optionParser.add_option(
             '--version',
             action='store_true',
@@ -470,14 +487,27 @@ class UtilityRunner(object):
             default=False,
             help='Display version information'
         )
+        self.optionParser.add_option(
+            '-i', '--interactive',
+            action='store_true',
+            dest='interactive',
+            default=False,
+            help='Start interactive mode'
+        )
+        self.optionParser.add_option(
+            '-v', '--verbose',
+            action='store_true',
+            dest='isVerbose',
+            default=False,
+            help='Increase verbosity'
+        )
         self.optionParser.add_option(
             '--config',
             action='store',
-            dest='config_file_path',
+            dest='configPath',
             default='',
-            help='Path to configuration file of service you wish to administer. ' + \
-                 'If not defined defaults to environment variable ' + \
-                 '%s if set.' % self.configFilePathEnvironVariableName
+            help='Path to service configuration file. Sets ' + \
+                 '%s in execution environment' % self.configFilePathEnvironVariableName
         )
         #self.optionParser.add_option(
         #    '--system',
