@@ -1,4 +1,4 @@
-from dm.command import Command
+from dm.command.base import Command
 
 class StateCommand(Command):
     "Abstract State command."
@@ -22,7 +22,8 @@ class StateCreate(StateCommand):
             self.raiseError(message)
         else:
             try:
-                self.state = self.states.create(self.name)
+                self.object = self.states.create(self.name)
+                self.state = self.object
                 self.commitSuccess()
             except Exception, inst:
                 message = "Couldn't create that state: %s" % str(inst)
