@@ -71,8 +71,8 @@ class SystemDictionary(dict):
         self[HTTPS_PORT]          = '443'
         self[URI_PREFIX]          = ''
         self[MEDIA_PATH]          = ''
-        self[MEDIA_HOST]          = '' # Defaults to configured DOMAIN_NAME.
-        self[MEDIA_PORT]          = '' # Defaults to configured HTTP_PORT.
+        self[MEDIA_HOST]          = ''
+        self[MEDIA_PORT]          = '' 
         self[MEDIA_PREFIX]        = '/media'
         # For values of the TIMEZONE word, please read the information
         # about the TZ environment variable in this tzset() reference:
@@ -147,8 +147,8 @@ class SystemDictionary(dict):
 
     def setWordsFromWords(self):
         # Media host and post.
-        if not self[MEDIA_HOST]:
-            self[MEDIA_HOST] = self[DOMAIN_NAME]
+        #if not self[MEDIA_HOST]:
+        #    self[MEDIA_HOST] = self[DOMAIN_NAME]
         if not self[MEDIA_PORT]:
             self[MEDIA_PORT] = self[HTTP_PORT]
         # Database super user.
@@ -243,6 +243,7 @@ class SystemDictionary(dict):
         return self.getSystemName().capitalize()
 
     def getDomainName(self):
+        # Todo: This is used for sending mail, doesn't help with Web UI, so move to 'MAIL_DOMAIN'?
         import platform
         return platform.node()
 
