@@ -14,7 +14,8 @@ SECRET_KEY = dictionary[dictionarywords.DJANGO_SECRET_KEY]
 ## Settings needing to be defined by a settings.main module.
 
 ROOT_URLCONF = ''
-
+DATABASE_ENGINE = 'dummy'
+#DATABASE_ENGINE = 'postgresql' # Needed to make Django v0.96.3 load 500.html?
 
 #
 ## Settings that are apparently extra to requirements!
