@@ -22,6 +22,9 @@ def suite():
         unittest.makeSuite(TestInteger_Zero),
         unittest.makeSuite(TestInteger_NonZero),
         unittest.makeSuite(TestInteger_Negative),
+        unittest.makeSuite(TestFloat_Zero),
+        unittest.makeSuite(TestFloat_NonZero),
+        unittest.makeSuite(TestFloat_Negative),
         unittest.makeSuite(TestImageFile),
         unittest.makeSuite(TestHasA_Null),
         unittest.makeSuite(TestHasMany_Null),
@@ -234,6 +237,39 @@ class TestInteger_Negative(MetaAttrTestCase):
     dbValue = -12
 
 
+class TestFloat_Zero(MetaAttrTestCase):
+    
+    fieldClass = dm.dom.meta.Float
+    typeName = 'Float'
+    isValueObject = True
+    htmlValue = '0'
+    htmlRepr = 0
+    domValue = 0
+    dbValue = 0
+
+
+class TestFloat_NonZero(MetaAttrTestCase):
+    
+    fieldClass = dm.dom.meta.Float
+    typeName = 'Float'
+    isValueObject = True
+    htmlValue = '12.1'
+    htmlRepr = 12.1
+    domValue = 12.1
+    dbValue = 12.1
+
+
+class TestFloat_Negative(MetaAttrTestCase):
+    
+    fieldClass = dm.dom.meta.Float
+    typeName = 'Float'
+    isValueObject = True
+    htmlValue = '-12.1'
+    htmlRepr = -12.1
+    domValue = -12.1
+    dbValue = -12.1
+
+
 class TestImageFile(MetaAttrTestCase):
 
     fieldClass = dm.dom.meta.ImageFile
