@@ -2,7 +2,7 @@ import os.path
 from dm.ioc import *
 from dm.dictionarywords import PLUGIN_DIR_PATH
 
-class FileSystemPathBuilder(object):
+class FileSystem(object):
 
     dictionary = RequiredFeature('SystemDictionary')
     logger = RequiredFeature('Logger')
@@ -22,3 +22,8 @@ class FileSystemPathBuilder(object):
         "Returns path of directory containing plugin filesystems."
         return os.path.join(self.getPluginsPath(), plugin.name)
 
+# Old name.
+class FileSystemPathBuilder(FileSystem):
+    pass 
+    
+
